@@ -10,14 +10,13 @@ from mitosheet.state import (
     DATAFRAME_SOURCE_MERGED,
     DATAFRAME_SOURCE_PASSED,
     DATAFRAME_SOURCE_PIVOTED,
-    FORMAT_ACCOUNTING,
-    FORMAT_CURRENCY,
-    FORMAT_DEFAULT,
-    FORMAT_K_M_B,
-    FORMAT_PERCENTAGE,
-    FORMAT_PLAIN_TEXT,
-    FORMAT_ROUND_DECIMALS,
-    FORMAT_SCIENTIFIC_NOTATION,
+    DATAFRAME_SOURCE_TRANSPOSED,
+    DATAFRAME_SOURCE_MELTED,
+    NUMBER_FORMAT_ACCOUNTING,
+    NUMBER_FORMAT_CURRENCY,
+    NUMBER_FORMAT_PERCENTAGE,
+    NUMBER_FORMAT_PLAIN_TEXT,
+    NUMBER_FORMAT_SCIENTIFIC_NOTATION,
 )
 from mitosheet.step_performers import (
     STEP_PERFORMERS,
@@ -60,6 +59,10 @@ def get_enum_from_ts_file(path, enum_name):
         # Remove trailing commas
         if enum_item_code_line.endswith(","):
             enum_item_code_line = enum_item_code_line[:-1]
+        
+        # If it's a comment, ignore it
+        if enum_item_code_line.startswith('//'):
+            continue
 
         # Split into keys and values
         [name, value] = enum_item_code_line.split(" = ")
@@ -148,7 +151,7 @@ def test_step_types_match():
     )
 
 
-def test_df_sources_matche():
+def test_df_sources_match():
     df_sources = get_enum_from_ts_file("./src/types.tsx", "DFSource")
     assert set(df_sources.values()) == set(
         [
@@ -157,6 +160,8 @@ def test_df_sources_matche():
             DATAFRAME_SOURCE_PIVOTED,
             DATAFRAME_SOURCE_MERGED,
             DATAFRAME_SOURCE_DUPLICATED,
+            DATAFRAME_SOURCE_TRANSPOSED,
+            DATAFRAME_SOURCE_MELTED
         ]
     )
 
@@ -167,19 +172,16 @@ def test_user_json_fields_match():
 
 
 def test_format_types_fields_match():
-    format_types = get_enum_from_ts_file("./src/types.tsx", "FormatType")
+    format_types = get_enum_from_ts_file("./src/types.tsx", "NumberColumnFormatEnum")
     format_types_values = format_types.values()
 
     assert set(format_types_values) == set(
         [
-            FORMAT_DEFAULT,
-            FORMAT_PLAIN_TEXT,
-            FORMAT_PERCENTAGE,
-            FORMAT_ACCOUNTING,
-            FORMAT_CURRENCY,
-            FORMAT_ROUND_DECIMALS,
-            FORMAT_K_M_B,
-            FORMAT_SCIENTIFIC_NOTATION,
+            NUMBER_FORMAT_PLAIN_TEXT,
+            NUMBER_FORMAT_PERCENTAGE,
+            NUMBER_FORMAT_ACCOUNTING,
+            NUMBER_FORMAT_CURRENCY,
+            NUMBER_FORMAT_SCIENTIFIC_NOTATION,
         ]
     )
 
